/**
@website noritake-elec.com
@version v1.2 (ME-N62-2)
@ide IAR
@brief I2C example code that demonstrates GT-CP functionality.
*/


#include "stm32f4xx.h"
#include "stm32f4_discovery.h"
#include "stdio.h"
#include "stdint.h"
#include "string.h"
#include <stddef.h>
#include "GTCP.h"
#include "GTCP_I2C.h"
#include "GTCP_SPI.h"
#include "GTCP_USART.h"

/*
  Demo states:
    - 0 = Menu
    - 1 = Photo
    - 2 = Keypad
    - 3 = Paint
  */

uint8_t RxDataArray[20];
uint8_t touchData[20];
uint32_t DELAY = 20;

int main()
{
  int position = 0;
  int demoState = 0;
  uint8_t photoFlag = 0;
  
  GTCP_I2C_Init(0x50);
  
  GTCP_Init(800, 480);
  
  //Outline type select command
  GTCP_setOutlineFontType(0x00);
    
  //Outline size select command
  GTCP_setFontSize(0x00);
  
  while(1){
    switch(demoState){
    case 0: //MENU
      int menuFlag = 0;
      photoFlag = 0;
      GTCP_selectWindow(0);
      GTCP_storedBitImageDraw(0x10, 0x00, 0x48, 800, 800, 480, 0x91);
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      while(menuFlag == 0){
        int check = 1;
        char *returnData;
        returnData = GTCP_I2C_MultiReadTRDY();
        while(check){
          if(returnData[position] == 0x10 && returnData[position + 1] == 0x11){
             int xBox = ((returnData[position + 4] & 0xff) << 8 | returnData[position + 3] & 0xff);
             int yBox = ((returnData[position + 6] & 0xff) << 8 | returnData[position + 5] & 0xff);
             int xBoxEnd = xBox + 15;
             int yBoxEnd = yBox + 15;
             
            //Check if the '1' key has been selected.
            if(xBox >= 169 && xBox <= 785 && yBox >= 10 && yBox <= 150 && photoFlag == 0){
              demoState = 1;
              menuFlag = 1;
            }
            //Check if the '2' key has been selected.
            else if(xBox >= 170 && xBox <= 784 && yBox >= 168 && yBox <= 307 && photoFlag == 0){
              demoState = 3;
              menuFlag = 1;
            }
            //Check if the '3' key has been selected.
            else if(xBox >= 169 && xBox <= 785 && yBox >= 325 && yBox <= 464 && photoFlag == 0){
              demoState = 2;
              menuFlag = 1;
            }
          }
          if(returnData[position + 7] != 0x10 || position > 256){
            memset(returnData, 0, 255);
            free(returnData);
            position = 0;
            check = 0;
          } else if(returnData[position + 7] == 0x10){
            position += 7;
            check = 1;
          }
        }
      }
      break;
    case 1: //PHOTO DEMO
      int photoDemoFlag = 0;
      photoFlag = 0;
      GTCP_storedBitImageDraw(0x10, 0x00, 0x18, 800, 800, 480, 0x91);
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      GTCP_selectWindow(0);
      
      while(photoDemoFlag == 0){
        int check = 1;
        char *returnData;
        returnData = GTCP_I2C_MultiReadTRDY();
        while(check){
          if(returnData[position] == 0x10 && returnData[position + 1] == 0x11){
             int xBox = ((returnData[position + 4] & 0xff) << 8 | returnData[position + 3] & 0xff);
             int yBox = ((returnData[position + 6] & 0xff) << 8 | returnData[position + 5] & 0xff);
             int xBoxEnd = xBox + 15;
             int yBoxEnd = yBox + 15;
             
            if(photoFlag){
              GTCP_storedBitImageDraw(0x10, 0x00, 0x18, 800, 800, 480, 0x91);
              photoFlag = 0;
            }
            //Check if photo 1 has been selected.
            else if(xBox >= 17 && xBox <= 390 && yBox >= 16 && yBox <= 228 && photoFlag == 0){
              GTCP_storedBitImageDraw(0x10, 0x00, 0x30, 800, 800, 480, 0x91);
              photoFlag = 1;
            }
            //Check if photo 2 has been selected.
            else if(xBox >= 411 && xBox <= 785 && yBox >= 16 && yBox <= 228 && photoFlag == 0){
              GTCP_storedBitImageDraw(0x10, 0x00, 0x24, 800, 800, 480, 0x91);
              photoFlag = 1;
            }
            //Check if photo 3 has been selected.
            else if(xBox >= 411 && xBox <= 785 && yBox >= 23 && yBox <= 458 && photoFlag == 0){
              GTCP_storedBitImageDraw(0x10, 0x00, 0x3c, 800, 800, 480, 0x91);
              photoFlag = 1;
            }
            
            //Check if << has been pressed.
            else if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
              demoState = 0;
              photoDemoFlag = 1;
            }
          }
          if(returnData[position + 7] != 0x10 || position > 256){
            memset(returnData, 0, 255);
            free(returnData);
            position = 0;
            check = 0;
          } else if(returnData[position + 7] == 0x10){
            position += 7;
            check = 1;
          }
        }
      }
      break;
    case 2: //KEYPAD DEMO
      int keypadDemoFlag = 0;
      photoFlag = 0;
      
      GTCP_storedBitImageDraw(0x10, 0x00, 0x0c, 800, 800, 480, 0x91);
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      GTCP_defineWindow(1, 16, 25, 490, 346);
      GTCP_selectWindow(1);
      GTCP_setCharacterColor(0x00, 0xff, 0x00);
      
      while(keypadDemoFlag == 0){
        int check = 1;
        char *returnData;
        returnData = GTCP_I2C_MultiReadTRDY();
        while(check){
          if(returnData[position] == 0x10 && returnData[position + 1] == 0x11){
             int xBox = ((returnData[position + 4] & 0xff) << 8 | returnData[position + 3] & 0xff);
             int yBox = ((returnData[position + 6] & 0xff) << 8 | returnData[position + 5] & 0xff);
             int xBoxEnd = xBox + 15;
             int yBoxEnd = yBox + 15;
             
            //Check if the '1' key has been selected.
            if(xBox >= 530 && xBox <= 601 && yBox >= 23 && yBox <= 95){
              GTCP_print('1');
            }
            //Check if the '2' key has been selected.
            else if(xBox >= 618 && xBox <= 690 && yBox >= 23 && yBox <= 95){
              GTCP_print('2');
            }
            //Check if the '3' key has been selected.
            else if(xBox >= 707 && xBox <= 778 && yBox >= 23 && yBox <= 95){
              GTCP_print('3');
            }
            //Check if the '4' key has been selected.
            else if(xBox >= 529 && xBox <= 600 && yBox >= 117 && yBox <= 188){
              GTCP_print('4');
            }
            //Check if the '5' key has been selected.
            else if(xBox >= 617 && xBox <= 689 && yBox >= 117 && yBox <= 188){
              GTCP_print('5');
            }
            //Check if the '6' key has been selected.
            else if(xBox >= 706 && xBox <= 777 && yBox >= 117 && yBox <= 188){
              GTCP_print('6');
            }
            //Check if the '7' key has been selected.
            else if(xBox >= 549 && xBox <= 601 && yBox >= 205 && yBox <= 277){
              GTCP_print('7');
            }
            //Check if the '8' key has been selected.
            else if(xBox >= 618 && xBox <= 689 && yBox >= 205 && yBox <= 277){
              GTCP_print('8');
            }
            //Check if the '9' key has been selected.
            else if(xBox >= 706 && xBox <= 778 && yBox >= 205 && yBox <= 277){
              GTCP_print('9');
            }
            //Check if the 'A' key has been selected.
            else if(xBox >= 528 && xBox <= 600 && yBox >= 298 && yBox <= 370){
              GTCP_print('A');
            }
            //Check if the '0' key has been selected.
            else if(xBox >= 617 && xBox <= 688 && yBox >= 298 && yBox <= 370){
              GTCP_print('0');
            }
            //Check if the 'E' key has been selected.
            else if(xBox >= 705 && xBox <= 777 && yBox >= 298 && yBox <= 370){
              GTCP_print('E');
            }
            //Check if the 'B' key has been selected.
            else if(xBox >= 528 && xBox <= 600 && yBox >= 384 && yBox <= 456){
              GTCP_print('B');
            }
            //Check if the 'C' key has been selected.
            else if(xBox >= 617 && xBox <= 688 && yBox >= 384 && yBox <= 456){
              GTCP_print('C');
            }
            //Check if the 'D' key has been selected.
            else if(xBox >= 705 && xBox <= 777 && yBox >= 384 && yBox <= 456){
              GTCP_print('D');
            }
            //Check if CLR has been pressed.
            else if(xBox >= 102 && xBox <= 173 && yBox >= 398 && yBox <= 470){
              GTCP_clearScreen();
            }
            else if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
              demoState = 0;
              keypadDemoFlag = 1;
            }
          }
          if(returnData[position + 7] != 0x10 || position > 256){
            memset(returnData, 0, 255);
            free(returnData);
            position = 0;
            check = 0;
          } else if(returnData[position + 7] == 0x10){
            position += 7;
            check = 1;
          }
        }
      }
      break;
    case 3: //PAINT DEMO
      int paintDemoFlag = 0;
      photoFlag = 0;
      
      GTCP_storedBitImageDraw(0x10, 0x00, 0x00, 800, 800, 480, 0x91);
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      GTCP_defineWindow(1, 0, 0, 800, 387);
      GTCP_selectWindow(1);
      GTCP_setCharacterColor(0xff, 0xff, 0xff);
      
      while(paintDemoFlag == 0){
        int check = 1;
        char *returnData;
        returnData = GTCP_I2C_MultiReadTRDY();
        while(check){
          if(returnData[position] == 0x10 && returnData[position + 1] == 0x11){
             int xBox = ((returnData[position + 4] & 0xff) << 8 | returnData[position + 3] & 0xff);
             int yBox = ((returnData[position + 6] & 0xff) << 8 | returnData[position + 5] & 0xff);
             int xBoxEnd = xBox + 15;
             int yBoxEnd = yBox + 15;
             
             //Check if user is trying to draw within the user window.
            if(xBox <= 800 && yBox <= 387){ 
              GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
            }
            //Check if RED color has been selected.
            else if(xBox >= 716 && xBox <= 788 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0xff, 0x00, 0x00);
            }
            //Check if YELLOW color has been selected.
            else if(xBox >= 628 && xBox <= 700 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0xff, 0xff, 0x00);
            }
            //Check if GREEN color has been selected.
            else if(xBox >= 540 && xBox <= 612 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0x00, 0xff, 0x00);
            }
            //Check if BLUE color has been selected.
            else if(xBox >= 453 && xBox <= 524 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0x00, 0x00, 0xff);
            }
            //Check if PURPLE color has been selected.
            else if(xBox >= 365 && xBox <= 436 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0x66, 0x00, 0xcc);
            }
            //Check if BLACK color has been selected.
            else if(xBox >= 277 && xBox <= 349 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0x00, 0x00, 0x00);
            }
            //Check if WHITE color has been selected.
            else if(xBox >= 189 && xBox <= 261 && yBox >= 398 && yBox <= 470){
              GTCP_setCharacterColor(0xff, 0xff, 0xff);
            }
            //Check if CLR has been pressed.
            else if(xBox >= 102 && xBox <= 173 && yBox >= 398 && yBox <= 470){
              GTCP_clearScreen();
            }
            else if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
              demoState = 0;
              paintDemoFlag = 1;
            }
          }
          if(returnData[position + 7] != 0x10 || position > 256){
            memset(returnData, 0, 255);
            free(returnData);
            position = 0;
            check = 0;
          } else if(returnData[position + 7] == 0x10){
            position += 7;
            check = 1;
          }
        }
      }
      break;
    }
  }
  return 0;
}