/**
@website noritake-elec.com
@version v1.2 (ME-N62-2)
@ide IAR
@brief SPI example code that demonstrates GT-CP functionality.
*/

#include "stm32f4xx.h"
#include "stm32f4_discovery.h"
#include "stdio.h"
#include "stdint.h"
#include "string.h"
#include <stddef.h>
#include "GTCP.h"
#include "GTCP_I2C.h"
#include "GTCP_SPI.h"
#include "GTCP_USART.h"

uint8_t RxDataArray[20];
uint8_t touchData[20];
uint32_t DELAY = 20;

int main()
{ 
  int demoState = 0;
  uint8_t photoFlag = 0;
  int status;
  int touch = 0;
  uint8_t data;
  
  GTCP_SPI_Init();
  startSPI();
  GTCP_Init(800, 480);
  
  //Outline type select command
  GTCP_setOutlineFontType(0x00);
    
  //Outline size select command
  GTCP_setFontSize(0x00);
  
  endSPI();
  
  while(1){
    switch(demoState){
    case 0: //MENU
      int menuFlag = 0;
      //status = 0;
      //touch = 0;
      //data = 0;
      photoFlag = 0;
      startSPI();
      
      GTCP_selectWindow(0);
      GTCP_storedBitImageDraw(0x10, 0x00, 0x48, 800, 800, 480, 0x91);
      
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      endSPI();
      
      while(menuFlag == 0){
        
        int valid = 0;
        int check = 1;
        int position = 0;
        
        status = readSPIstatus();
        if(status > 0 && status <= 63){
          startSPIRead();
          for(int i = 0; i < status; i++){
            data = readSPIData();
            if(valid && RxDataArray[1] == 0x11){
              RxDataArray[i] = data;
            }
            else if(valid && data == 0x11){
              RxDataArray[i] = data;
            }
            else if(data == 0x10 && valid == 0){
              i = 0;
              RxDataArray[i] = data;
              valid = 1;
            }
          }
          valid = 0;
          endSPI();
          int count = status;
          count /= 7;
          for(int i = 0; i < count; i++){
            if(RxDataArray[position + 1] == 0x11){
              startSPI();
              
              int xBox = ((RxDataArray[position + 4] & 0xff) << 8 | RxDataArray[position + 3] & 0xff);
              int yBox = ((RxDataArray[position + 6] & 0xff) << 8 | RxDataArray[position + 5] & 0xff);
              int xBoxEnd = xBox + 15;
              int yBoxEnd = yBox + 15;
            
              //GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
              
              //Check if the '1' key has been selected.
              if(xBox >= 169 && xBox <= 785 && yBox >= 10 && yBox <= 150 && photoFlag == 0){
                demoState = 1;
                menuFlag = 1;
              }
              //Check if the '2' key has been selected.
              else if(xBox >= 170 && xBox <= 784 && yBox >= 168 && yBox <= 307 && photoFlag == 0){
                demoState = 3;
                menuFlag = 1;
              }
              //Check if the '3' key has been selected.
              else if(xBox >= 169 && xBox <= 785 && yBox >= 325 && yBox <= 464 && photoFlag == 0){
                demoState = 2;
                menuFlag = 1;
              }
              
              endSPI();
            }
            position += 7;
          }
          for(int i = 0; i < status; i++){
            RxDataArray[i] = 0x00;
          }
        }
      }
      break;
    case 1: //PHOTO DEMO
      int photoDemoFlag = 0;
      //status = 0;
      //touch = 0;
      //data = 0;
      photoFlag = 0;
      startSPI();
      
      GTCP_selectWindow(0);
      GTCP_storedBitImageDraw(0x10, 0x00, 0x18, 800, 800, 480, 0x91);
      
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      endSPI();
      
      while(photoDemoFlag == 0){
        
        int valid = 0;
        int check = 1;
        int position = 0;
        
        status = readSPIstatus();
        if(status > 0 && status <= 63){
          startSPIRead();
          for(int i = 0; i < status; i++){
            data = readSPIData();
            if(valid && RxDataArray[1] == 0x11){
              RxDataArray[i] = data;
            }
            else if(valid && data == 0x11){
              RxDataArray[i] = data;
            }
            else if(data == 0x10 && valid == 0){
              i = 0;
              RxDataArray[i] = data;
              valid = 1;
            }
          }
          valid = 0;
          endSPI();
          int count = status;
          count /= 7;
          for(int i = 0; i < count; i++){
            if(RxDataArray[position + 1] == 0x11){
              startSPI();
              
              int xBox = ((RxDataArray[position + 4] & 0xff) << 8 | RxDataArray[position + 3] & 0xff);
              int yBox = ((RxDataArray[position + 6] & 0xff) << 8 | RxDataArray[position + 5] & 0xff);
              int xBoxEnd = xBox + 15;
              int yBoxEnd = yBox + 15;
            
              //GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
              
              if(photoFlag){
                GTCP_storedBitImageDraw(0x10, 0x00, 0x18, 800, 800, 480, 0x91);
                photoFlag = 0;
              }
              //Check if photo 1 has been selected.
              else if(xBox >= 17 && xBox <= 390 && yBox >= 16 && yBox <= 228 && photoFlag == 0){
                GTCP_storedBitImageDraw(0x10, 0x00, 0x30, 800, 800, 480, 0x91);
                photoFlag = 1;
              }
              //Check if photo 2 has been selected.
              else if(xBox >= 411 && xBox <= 785 && yBox >= 16 && yBox <= 228 && photoFlag == 0){
                GTCP_storedBitImageDraw(0x10, 0x00, 0x24, 800, 800, 480, 0x91);
                photoFlag = 1;
              }
              //Check if photo 3 has been selected.
              else if(xBox >= 411 && xBox <= 785 && yBox >= 23 && yBox <= 458 && photoFlag == 0){
                GTCP_storedBitImageDraw(0x10, 0x00, 0x3c, 800, 800, 480, 0x91);
                photoFlag = 1;
              }
              
              //Check if << has been pressed.
              else if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
                demoState = 0;
                photoDemoFlag = 1;
              }
              
              endSPI();
            }
            position += 7;
          }
          for(int i = 0; i < status; i++){
            RxDataArray[i] = 0x00;
          }
        }
      }
      break;
    case 2: //KEYPAD DEMO
      int keypadDemoFlag = 0;
      //status = 0;
      //touch = 0;
      //data = 0;
      photoFlag = 0;
      startSPI();
      
      GTCP_selectWindow(0);
      GTCP_storedBitImageDraw(0x10, 0x00, 0x0c, 800, 800, 480, 0x91);
      
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      GTCP_defineWindow(1, 16, 25, 490, 346);
      GTCP_selectWindow(1);
      GTCP_setCharacterColor(0x00, 0xff, 0x00);
      
      endSPI();
      
      while(keypadDemoFlag == 0){
        
        int valid = 0;
        int check = 1;
        int position = 0;
        
        status = readSPIstatus();
        if(status > 0 && status <= 63){
          startSPIRead();
          for(int i = 0; i < status; i++){
            data = readSPIData();
            if(valid && RxDataArray[1] == 0x11){
              RxDataArray[i] = data;
            }
            else if(valid && data == 0x11){
              RxDataArray[i] = data;
            }
            else if(data == 0x10 && valid == 0){
              i = 0;
              RxDataArray[i] = data;
              valid = 1;
            }
          }
          valid = 0;
          endSPI();
          int count = status;
          count /= 7;
          for(int i = 0; i < count; i++){
            if(RxDataArray[position + 1] == 0x11){
              startSPI();
              
              int xBox = ((RxDataArray[position + 4] & 0xff) << 8 | RxDataArray[position + 3] & 0xff);
              int yBox = ((RxDataArray[position + 6] & 0xff) << 8 | RxDataArray[position + 5] & 0xff);
              //int xBoxEnd = xBox + 15;
              //int yBoxEnd = yBox + 15;
            
              //GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
              
              //Check if CLR has been pressed.
              if(xBox >= 102 && xBox <= 173 && yBox >= 398 && yBox <= 470){
                GTCP_clearScreen();
              }
              if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
                demoState = 0;
                keypadDemoFlag = 1;
              }
              if(xBox >= 530 && xBox <= 778 && yBox >= 23 && yBox <= 277){
                //Check if the '1' key has been selected.
                if(xBox >= 530 && xBox <= 601 && yBox >= 23 && yBox <= 95){
                  writeSPI('1');
                }
                //Check if the '2' key has been selected.
                if(xBox >= 618 && xBox <= 690 && yBox >= 23 && yBox <= 95){
                  writeSPI('2');
                }
                //Check if the '3' key has been selected.
                if(xBox >= 707 && xBox <= 778 && yBox >= 23 && yBox <= 95){
                  writeSPI('3');
                }
                //Check if the '4' key has been selected.
                if(xBox >= 529 && xBox <= 600 && yBox >= 117 && yBox <= 188){
                  writeSPI('4');
                }
                //Check if the '5' key has been selected.
                if(xBox >= 617 && xBox <= 689 && yBox >= 117 && yBox <= 188){
                  writeSPI('5');
                }
                //Check if the '6' key has been selected.
                if(xBox >= 706 && xBox <= 777 && yBox >= 117 && yBox <= 188){
                  writeSPI('6');
                }
                //Check if the '7' key has been selected.
                if(xBox >= 549 && xBox <= 601 && yBox >= 205 && yBox <= 277){
                  writeSPI('7');
                }
                //Check if the '8' key has been selected.
                if(xBox >= 618 && xBox <= 689 && yBox >= 205 && yBox <= 277){
                  writeSPI('8');
                }
                //Check if the '9' key has been selected.
                if(xBox >= 706 && xBox <= 778 && yBox >= 205 && yBox <= 277){
                  writeSPI('9');
                }
              }
              if(xBox >= 528 && xBox <= 777 && yBox >= 298 && yBox <= 456){
                //Check if the 'A' key has been selected.
                if(xBox >= 528 && xBox <= 600 && yBox >= 298 && yBox <= 370){
                  writeSPI('A');
                }
                //Check if the '0' key has been selected.
                if(xBox >= 617 && xBox <= 688 && yBox >= 298 && yBox <= 370){
                  writeSPI('0');
                }
                //Check if the 'E' key has been selected.
                if(xBox >= 705 && xBox <= 777 && yBox >= 298 && yBox <= 370){
                  writeSPI('E');
                }
                //Check if the 'B' key has been selected.
                if(xBox >= 528 && xBox <= 600 && yBox >= 384 && yBox <= 456){
                  writeSPI('B');
                }
                //Check if the 'D' key has been selected.
                if(xBox >= 705 && xBox <= 777 && yBox >= 384 && yBox <= 456){
                  writeSPI('D');
                }
                //Check if the 'C' key has been selected.
                if(xBox >= 617 && xBox <= 688 && yBox >= 384 && yBox <= 456){
                  writeSPI('C');
                }
              }
              
              
              endSPI();
            }
            position += 7;
          }
          for(int i = 0; i < status; i++){
            RxDataArray[i] = 0x00;
          }
        }
      }
      break;
    case 3: //PAINT DEMO
      int paintDemoFlag = 0;
      //status = 0;
      //touch = 0;
      //data = 0;
      photoFlag = 0;
      startSPI();
      
      GTCP_selectWindow(0);
      GTCP_storedBitImageDraw(0x10, 0x00, 0x00, 800, 800, 480, 0x91);
      
      GTCP_touchDataEnable(0x01);
      GTCP_touchModeSelect(0x0a);
      GTCP_coordinatesMode(0x00);
      
      GTCP_defineWindow(1, 0, 0, 800, 387);
      GTCP_selectWindow(1);
      GTCP_setCharacterColor(0xff, 0xff, 0xff);
      
      endSPI();
      
      while(paintDemoFlag == 0){
        
        int valid = 0;
        int check = 1;
        int position = 0;
        
        status = readSPIstatus();
        if(status > 0 && status <= 63){
          startSPIRead();
          for(int i = 0; i < status; i++){
            data = readSPIData();
            if(valid && RxDataArray[1] == 0x11){
              RxDataArray[i] = data;
            }
            else if(valid && data == 0x11){
              RxDataArray[i] = data;
            }
            else if(data == 0x10 && valid == 0){
              i = 0;
              RxDataArray[i] = data;
              valid = 1;
            }
          }
          valid = 0;
          endSPI();
          int count = status;
          count /= 7;
          for(int i = 0; i < count; i++){
            if(RxDataArray[position + 1] == 0x11){
              startSPI();
              
              int xBox = ((RxDataArray[position + 4] & 0xff) << 8 | RxDataArray[position + 3] & 0xff);
              int yBox = ((RxDataArray[position + 6] & 0xff) << 8 | RxDataArray[position + 5] & 0xff);
              int xBoxEnd = xBox + 15;
              int yBoxEnd = yBox + 15;
            
              //GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
              
              //Check if user is trying to draw within the user window.
              if(xBox <= 800 && yBox <= 387){ 
                GTCP_drawLineBox(0x02, 0x01, xBox, yBox, xBoxEnd, yBoxEnd);
              }
              //Check if RED color has been selected.
              else if(xBox >= 716 && xBox <= 788 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0xff, 0x00, 0x00);
              }
              //Check if YELLOW color has been selected.
              else if(xBox >= 628 && xBox <= 700 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0xff, 0xff, 0x00);
              }
              //Check if GREEN color has been selected.
              else if(xBox >= 540 && xBox <= 612 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0x00, 0xff, 0x00);
              }
              //Check if BLUE color has been selected.
              else if(xBox >= 453 && xBox <= 524 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0x00, 0x00, 0xff);
              }
              //Check if PURPLE color has been selected.
              else if(xBox >= 365 && xBox <= 436 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0x66, 0x00, 0xcc);
              }
              //Check if BLACK color has been selected.
              else if(xBox >= 277 && xBox <= 349 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0x00, 0x00, 0x00);
              }
              //Check if WHITE color has been selected.
              else if(xBox >= 189 && xBox <= 261 && yBox >= 398 && yBox <= 470){
                GTCP_setCharacterColor(0xff, 0xff, 0xff);
              }
              //Check if CLR has been pressed.
              else if(xBox >= 102 && xBox <= 173 && yBox >= 398 && yBox <= 470){
                GTCP_clearScreen();
              }
              else if(xBox >= 17 && xBox <= 88 && yBox >= 386 && yBox <= 458 && photoFlag == 0){
                demoState = 0;
                paintDemoFlag = 1;
              }
              endSPI();
            }
            position += 7;
          }
          for(int i = 0; i < status; i++){
            RxDataArray[i] = 0x00;
          }
        }
      }
      break;
    }
  }
  return 0;
}